﻿using UnityEngine;
using System.Collections;

public class GameManager : Singleton<GameManager> {

	// We'll need our elemental switch UI stored here
	public GameObject elementalSwitchUI;
	// We'll need its attached FollowObject
	private FollowObject elementalFollowObject;
	// Declare the UIButton array
	UIButton[] allButtons;
	// Current power source with elemental switch UI
	public PowerSource currentPowerSource;

	// At Start
	void Start () {
		// Retrieve the elemental switch UI’s FolloObject
		elementalFollowObject =
			elementalSwitchUI.GetComponent<FollowObject>();
		// Hide elemental switch UI
		elementalSwitchUI.SetActive(false);
		// Retrieve all elemental buttons
		allButtons =
			elementalSwitchUI.GetComponentsInChildren<UIButton>(true);
	}

	// Show or hide elemental switch UI
	public void ShowElementalSwitch(Transform targetObject)
	{
		// If the target object to follow isn't null 
		if(targetObject != null)
		{
			// Set the elements switch's current power source
			currentPowerSource = targetObject.GetComponent<PowerSource>();
			// Enable the elemental switch UI
			elementalSwitchUI.SetActive(true);
			// Make sure it follows the target
			elementalFollowObject.target = targetObject;
			// Set its scale to {0.01,0.01,0.01}
			elementalSwitchUI.transform.localScale =
				new Vector3(0.01f,0.01f,0.01f);
			// Start a scale tween on it
			TweenScale.Begin(elementalSwitchUI, 0.2f, Vector3.one);
		}
		// If the target object is null
		else
		{
			// Disable the elemental switch UI
			elementalSwitchUI.SetActive (false);
		}
	}

	// Execute when Fire button is pressed
	public void FirePressed()
	{
		// Request the power source to switch element;
		currentPowerSource.SwitchElement(Elements.Type.Fire);
	}
	
	// Execute when Ice button is pressed
	public void IcePressed()
	{
		// Request the power source to switch element;
		currentPowerSource.SwitchElement(Elements.Type.Ice);
	}
	
	// Execute when Lightning button is pressed
	public void LightningPressed()
	{
		// Request the power source to switch element;
		currentPowerSource.SwitchElement(Elements.Type.Lightning);
	}
	
	// Execute when Water button is pressed
	public void WaterPressed()
	{
		// Request the power source to switch element;
		currentPowerSource.SwitchElement(Elements.Type.Water);
	}

	// Enable all elemental buttons
	public void EnableAllButtons()
	{
		// For each elemental button
		foreach(UIButton currentButton in allButtons)
		{
			// Mark it as enabled
			currentButton.isEnabled = true;
			// Update its color
			currentButton.UpdateColor(true);
		}
	}

	// Used to enable / disable elemental buttons
	public void SetButtonState(Elements.Type type, bool state)
	{
		// For each button in allButtons[]
		foreach (UIButton currentButton in allButtons)
		{
			// If currentButton is the one to enable/disable
			if (currentButton.name == type.ToString())
			{
				// Change its isEnabled state
				currentButton.isEnabled = state;
				// Update its color now
				currentButton.UpdateColor(true);
				return;
			}
		}
	}

	// EXISTING METHODS

	public Transform GetElementalSwitchUITarget()
	{
		return elementalFollowObject.target;
	}
}
