﻿using UnityEngine;
using System.Collections;

public class MenuManager : Singleton<MenuManager> {

	// Assign in this array objects to enable
	public GameObject[] enableAtAwake;
	// And here ones to disable
	public GameObject[] disableAtAwake;
	// We'll need the UI camera
	public Camera uiCamera;
	// We'll need the UI background
	public GameObject background;

	// Before anything happens
	private void Awake ()
	{
		// Enable all objects in enableAtAwake array
		foreach(GameObject currentGO in enableAtAwake)
		{
			if(currentGO != null)
				currentGO.SetActive(true);
		}
		
		// Disable all objects in disableAtAwake array
		foreach(GameObject currentGO in disableAtAwake)
		{
			if(currentGO != null)
				currentGO.SetActive(false);
		}
	}

	public void LoadGameScene()
	{
		// Load the Game scene now
		Application.LoadLevel("Game");
		// Launch the enter game routine
		StartCoroutine("EnterGameRoutine");
	}

	// EnterGame Coroutine
	private IEnumerator EnterGameRoutine()
	{
		yield return new WaitForSeconds(0.1f);
		// Fade out the UI background
		TweenAlpha.Begin(background, 0.5f, 0);
		// Wait for the tween to finish
		yield return new WaitForSeconds(0.5f);
		// Hide the main menu UI by disabling cam
		uiCamera.enabled = false;
	}
	
	// Update is called once per frame
	void Update () {
	
	}

	void Start()
	{
		base.Start();
	}

	// Method called when we want to exit
	public void Exit ()
	{
		// If currently in Unity Editor
		#if UNITY_EDITOR
		// Stop play mode
		UnityEditor.EditorApplication.isPlaying = false;
		#endif
		// Exit the game
		Application.Quit();
	}

}
