﻿using UnityEngine;
using System.Collections;

public class PowerFeed : MonoBehaviour {

	// EXISTING VARIABLES

	// This power feed's current element type
	public Elements.Type feedsOn;
	// This power feed's opposing element;
	public Elements.Type opposingType;
	// We'll need the associated light
	private Light light;
	// We'll need the mesh renderer
	private MeshRenderer mesh;
	// The power feed's current level
	private int currentLevel = 0;


	// EXISTING METHODS

	// Upon interaction, request player use his element
	public void Interact()
	{
		PlayerController.Instance.UseElement(PlayerController.Instance.currentType, gameObject);
	}

	// Initialize values at start
	private void Start()
	{
		// Retrieve associated light
		light = GetComponentInChildren<Light>();
		// Retrieve the mesh renderer
		mesh = GetComponentInChildren<MeshRenderer>();
		// Set the default element for this feed
		SetNewElement(feedsOn);
	}

	// Method that sets a new element for this feed
	public void SetNewElement(Elements.Type newElement)
	{
		// Update the type with the requested element
		feedsOn = newElement;
		// Declare the new light color
		Color32 newLightColor;
		// The new material's path
		string newMatPath = "3D/Materials/" + newElement.ToString();
		// Assign the new material
		mesh.material = Resources.Load(newMatPath) as Material;
		
		// Configure color depending on new element
		switch(newElement)
		{
		case Elements.Type.Fire:
			newLightColor = new Color32(255, 140, 90, 255);
			opposingType = Elements.Type.Ice;
			break;
		case Elements.Type.Ice:
			opposingType = Elements.Type.Fire;
			newLightColor = new Color32(230, 255, 250, 255);
			break;
		case Elements.Type.Lightning:
			opposingType = Elements.Type.Water;
			newLightColor = new Color32(40, 255, 255, 255);
			break;
			// If it's water, or anything else
		default:
			opposingType = Elements.Type.Lightning;
			newLightColor = new Color32(0, 50, 255, 255);
			break;
		}
		
		// Assign the new light color
		light.color = newLightColor;
	}

	public void Feed()
	{
		SetLevel(currentLevel+1);
	}

	public void SetLevel(int newLevel)
	{
		currentLevel = newLevel;
		float newScaleValue = currentLevel * 0.3f;
		TweenScale.Begin(gameObject, 1f, transform.localScale + (Vector3.one * newScaleValue));
		GetComponent<ApproachOnClick>().stoppingDistance += newScaleValue;
	}


}
