﻿using UnityEngine;
using System.Collections;

public class PlayerController : Singleton<PlayerController> {

	public float speed = 10;
	public float energy = 100;

	public float stopDistance = 1f;


	private Vector3 destination = Vector3.zero;
	private Vector3 moveDirection = Vector3.zero;

	private CharacterController characterController;
	private GameObject objectToInteract;

	public Elements.Type currentType;

	private MeshRenderer mesh;
	private Light light;


	void Awake()
	{
		characterController = GetComponent<CharacterController>();
		mesh = GetComponentInChildren<MeshRenderer>();
		light = GetComponentInChildren<Light>();
		SetNewElement(currentType);
	}

	public void SetDestination(Vector3 newDestination)
	{
		SetDestination(null, newDestination, 0.5f);
	}

	// Set destination now, 
	public void SetDestination(GameObject newObjectToInteract, Vector3 newDestination, float destinationStopDistance)
	{
		objectToInteract = newObjectToInteract;
		Vector3 targetPos = new Vector3(newDestination.x, transform.position.y, newDestination.z);
		stopDistance = destinationStopDistance;
		float distanceFromTarget = Vector3.Distance(transform.position, targetPos);

		if(distanceFromTarget > stopDistance)
		{
			destination = targetPos;
			moveDirection = destination - transform.position;
			moveDirection.Normalize();
		}

	}

	void Update()
	{
		MoveUpdate();
	}

	void MoveUpdate()
	{
		if(HasADestination())
		{
			Vector3 finalMovement = moveDirection * (speed * (energy * 0.01f));
			characterController.Move(finalMovement * Time.deltaTime);

			if(ArrivedAtDestination())
			{
				StopNow();
				Interact();
			}
		}
	}

	private void Interact()
	{
		if(objectToInteract != null)
		{
			objectToInteract.SendMessage("Interact", SendMessageOptions.DontRequireReceiver);
		}
	}

	// Method that sets a new element for the player
	public void SetNewElement(Elements.Type newElement)
	{
		// Update the type with the requested element
		currentType = newElement;
		// Declare the new light color
		Color32 newLightColor;
		// The new material's path
		string newMatPath = "3D/Materials/" + newElement.ToString();
		// Assign the new material
		mesh.material = Resources.Load(newMatPath) as Material;
		
		// Configure color depending on new element
		switch(newElement)
		{
		case Elements.Type.Fire:
			newLightColor = new Color32(255, 140, 90, 255);
			break;
		case Elements.Type.Ice:
			newLightColor = new Color32(230, 255, 250, 255);
			break;
		case Elements.Type.Lightning:
			newLightColor = new Color32(40, 255, 255, 255);
			break;
			// If it's water, or anything else
		default:
			newLightColor = new Color32(0, 50, 255, 255);
			break;
		}
		
		// Assign the new light color
		light.color = newLightColor;
	}

	public bool ArrivedAtDestination()
	{
		bool arrivedAtDestination = false;

		float distanceFromDestination = Vector3.Distance(transform.position, destination);

		if(distanceFromDestination < stopDistance)
			arrivedAtDestination = true;

			return arrivedAtDestination;
	}

	public bool HasADestination()
	{
		bool hasADestination = false;

		if(moveDirection != Vector3.zero || destination != Vector3.zero)
			hasADestination = true;

		return hasADestination;
	}

	public void StopNow()
	{
		destination = Vector3.zero;
		moveDirection = Vector3.zero;
	}

	public void UseElement(Elements.Type elementToUse, GameObject target)
	{
		PowerFeed targetFeed = target.GetComponent<PowerFeed>();

		if(targetFeed.feedsOn == currentType)
		{
			targetFeed.Feed();
			// Increase Score
			ScoreController.Instance.currentScore += 1000;
		}
	}
}
