﻿using UnityEngine;
using System.Collections;

public class ScoreController : Singleton<ScoreController> {

	// We'll need to store the score label
	private UILabel label;
	// We'll need to separate the displayed score
	private int previousScore;
	// The private _currentScore value
	private int _currentScore;

	// The public currentscore with custom setter
	public int currentScore
	{
		get
		{
			return _currentScore;
		}
		set
		{
			// Update the previous score to current score
			previousScore = _currentScore;
			// Update the private _currentScore value
			_currentScore = value;
			// Update the label with new score
			UpdateLabel();
		}
	}
	
	// At start
	private void Start ()
	{
		// Get the score counter's label
		label = GetComponentInChildren<UILabel>();
		// Set the currentScore value to 0
		currentScore = 0;
	}

	// Method to update the score label
	public void UpdateLabel()
	{
		// Launch the coroutine to update the label
		StartCoroutine(UpdateLabelRoutine());
	}

	// Coroutine that updates the label
	private IEnumerator UpdateLabelRoutine()
	{
		// Scale up the score label to 1.2
		UITweener tween =
			TweenScale.Begin(label.gameObject, 0.1f, Vector3.one * 1.2f);
		
		// Wait for the scale tween to finish
		yield return new WaitForSeconds(0.1f);
		
		// Calculate difference between old and new score
		int scoreDelta = currentScore - previousScore;
		
		// While previous score is below current score...
		while(previousScore < currentScore)
		{
			// ...Increase the previousScore value
			previousScore += Mathf.CeilToInt(scoreDelta * Time.deltaTime * 3.5f);
			// Set the label to the previousScore value
			label.text = previousScore.ToString();
			// Wait for next frame
			yield return null;
		}
		
		// When score has reached final score value
		// Update the score label with current score
		label.text = currentScore.ToString();
		
		// Wait a little
		yield return new WaitForSeconds(0.3f);
		// Re-scale down the score label
		TweenScale.Begin(label.gameObject, 0.1f, Vector3.one);
	}


	void Update()
	{
		if(Input.GetKeyDown(KeyCode.KeypadPlus))
			currentScore += 1000;
	}
}
