﻿using UnityEngine;
using System.Collections;

public class ApproachOnClick : MonoBehaviour {

	// ZXISTING VARIABLES
	#if UNITY_4_5
	[Tooltip("Checked: Player moves to clicked position\nUnchecked: Player moves to clicked object's pivot")]
	#endif
	public bool precise = false;
	#if UNITY_4_5
	[Tooltip("Distance from which the Player will stop for this object")]
	#endif
	public float stoppingDistance = 3.5f;
	// Used to cancel a movement if the object is dragged
	private bool validMoveRequest = true;
	// Used to know if the object is draggable
	private bool isDraggable = false;

	// If a Press event occurs on this object
	void OnPress(bool pressed)
	{
		if(pressed)
		{
			// Declare a default ID to check
			int idToCheck = 0;
			// If we're in the editor
			/*if(Application.isEditor)
			{
				// Set idToCheck to left click
				idToCheck = -1;
			}*/

			// Check if touchID is the one to check
			if(UICamera.currentTouchID == idToCheck)
			{
				// Set it to be a valid movement request
				validMoveRequest = true;
			}
			// If it's not
			else
			{
				// Set it to be an invalid movement request
				validMoveRequest = false;
			}
		}
		// If the object is released
		else
		{
			// If the movement request is still valid 
			if(validMoveRequest)
			{
				// Set destination to the object's pivot
				Vector3 destination = transform.position;
				
				// If the precise bool is checked...
				if(precise)
				{
					// ...Set destination to clicked position
					destination = UICamera.lastWorldPosition;
				}
				
				// Request player to move with stopping distance
				PlayerController.Instance.SetDestination(
					gameObject, destination, stoppingDistance);
			}
		}
	}

	// If a drag event occurs on this object
	public void OnDrag(Vector2 delta)
	{
		// If the object is draggable...
		if(isDraggable)
		{
			// ...The object moves. Mark as invalid movement request
			validMoveRequest = false;
		}
	}

	// Method that cancels the movement request
	public void CancelMovementRequest()
	{
		// Cancel the movement request
		validMoveRequest = false;
	}
	
	// EXISTING METHODS
	// At Start
	void Start()
	{
		// If the object has the UIDragObject component...
		if(GetComponent<UIDragObject>() != null)
		{
			// ...It means it's a draggable object. Set the according variable to true
			isDraggable = true;
		}
	}
}
