﻿using UnityEngine;
using System.Collections;

public class CustomizableUIElement : MonoBehaviour {

	// We'll need the widget's UIDragObject
	private UIDragObject dragObject;

	private void Start()
	{
		// Retrieve the widget's UIDragObject
		dragObject = GetComponent<UIDragObject>();
		// Make sure the widget isn't draggable
		SetDraggable(false);
	}

	// Sets the widget draggable or not
	public void SetDraggable(bool draggable)
	{
		// If draggable and hovered object is still this one
		if(draggable && UICamera.hoveredObject == gameObject)
		{
			// Disable the UIDragObject's movement
			dragObject.dragMovement = Vector3.one;
			// Make the widget transparent
			TweenAlpha.Begin(gameObject, 0.2f, 0.4f);
			// Make the widget slightly bigger
			TweenScale.Begin(gameObject, 0.2f, Vector3.one * 1.15f);
			// Pause the game
			GameManager.Instance.SetPause(true);
		}
		// If it's now not draggable
		else
		{
			// Re-enable the UIDragObject's movement
			dragObject.dragMovement = Vector3.zero;
			// Reset the widget's alpha value
			TweenAlpha.Begin(gameObject, 0.2f, 1f);
			// Reset the widget's original size
			TweenScale.Begin(gameObject, 0.2f, Vector3.one);
			// Cancel the hold feedback if there is one
			GameManager.Instance.CancelHoldFeedback();
			// Unpause the game
			GameManager.Instance.SetPause(false);
		}
	}

	void OnPress(bool pressed)
	{
		// If widget has just been pressed, show hold feedback
		if(pressed)
		{
			// Parameters to pass to the Coroutine
			object[] parameters = new object[2]{transform, 0.35f};
			// Cancel hold feedback if there is one
			GameManager.Instance.CancelHoldFeedback();
			// Set the HoldFeedback to follow a 3D UI widget
			GameManager.Instance.HoldFollowsEnvironment(false);
			// Start the HoldFeedback routine
			GameManager.Instance.StartCoroutine("HoldFeedbackRoutine", parameters);
		}
		// If widget has just been released
		else
		{
			// Make sure the widget isn't draggable
			SetDraggable(false);
		}
	}
	
	// Update is called once per frame
	void Update () {
	
	}
}
