﻿using UnityEngine;
using System.Collections;

public class AtlasSwitchController : MonoBehaviour {

	// The reference atlas
	public UIAtlas referenceAtlas;
	
	// Screen width thresholds
	public int HDFromWidth = 800;
	public int SHDFromWidth = 1600;
	
	// Atlases for all qualities
	public UIAtlas SDAtlas;
	public UIAtlas HDAtlas;
	public UIAtlas SHDAtlas;
	
	// This will store the replacement atlas
	private UIAtlas replacementAtlas;

	// Before anything happens
	void Awake ()
	{
		// Retrieve the screen’s width
		int screenWidth = Screen.width;

		// Set replacementAtlas to SDAtlas by default
		replacementAtlas = SDAtlas;

		// If the screen width exceeds SHD threshold
		if(screenWidth >= SHDFromWidth)
		{
			// Set the SHDAtlas as replacement
			replacementAtlas = SHDAtlas;
		}
		// If the screen width exceeds HD threshold
		else if(screenWidth >= HDFromWidth)
		{
			// Set the HDAtlas as replacement
			replacementAtlas = HDAtlas;
		}

		// Update the referenceAtlas with the replacement
		referenceAtlas.replacement = replacementAtlas;

		// Make all widgets pixel perfect now
		MakeAllWidgetsPixelPerfect();
	}

	private void MakeAllWidgetsPixelPerfect()
	{
		// Declare a widget array to store them
		UIWidget[] allWidgets;
		// Retrieve all widgets in scene
		allWidgets = Object.FindObjectsOfType<UIWidget>();
		
		// For each of these widgets
		foreach(UIWidget widget in allWidgets)
		{
			// Make th widget pixel perfect
			widget.MakePixelPerfect();
		}
	}
}
